macro_rules! status {
($color:expr, $status:expr, $msg:expr) => { ... };
($color:expr, $status:expr, $fmt:expr, $($arg:tt)+) => { ... };
}Expand description
Print a status message with the given color (if colors are enabled)
macro_rules! status {
($color:expr, $status:expr, $msg:expr) => { ... };
($color:expr, $status:expr, $fmt:expr, $($arg:tt)+) => { ... };
}Print a status message with the given color (if colors are enabled)